#[non_exhaustive]pub struct CallAnswerEventContent {
pub answer: SessionDescription,
pub call_id: OwnedVoipId,
pub party_id: Option<OwnedVoipId>,
pub version: VoipVersionId,
pub capabilities: CallCapabilities,
pub sdp_stream_metadata: BTreeMap<String, StreamMetadata>,
}events only.Expand description
The content of an m.call.answer event.
This event is sent by the callee when they wish to answer the call.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.answer: SessionDescriptionThe VoIP session description object.
call_id: OwnedVoipIdA unique identifier for the call.
party_id: Option<OwnedVoipId>Required in VoIP version 1. A unique ID for this session for the duration of the call.
version: VoipVersionIdThe version of the VoIP specification this messages adheres to.
capabilities: CallCapabilitiesunstable-msc2747 only.The VoIP capabilities of the client.
sdp_stream_metadata: BTreeMap<String, StreamMetadata>Added in VoIP version 1. Metadata describing the streams that will be sent.
This is a map of stream ID to metadata about the stream.
Implementations
Sourceimpl CallAnswerEventContent
impl CallAnswerEventContent
Sourcepub fn new(
answer: SessionDescription,
call_id: OwnedVoipId,
version: VoipVersionId,
) -> CallAnswerEventContent
pub fn new( answer: SessionDescription, call_id: OwnedVoipId, version: VoipVersionId, ) -> CallAnswerEventContent
Creates an CallAnswerEventContent with the given answer, call ID and VoIP version.
Sourcepub fn version_0(
answer: SessionDescription,
call_id: OwnedVoipId,
) -> CallAnswerEventContent
pub fn version_0( answer: SessionDescription, call_id: OwnedVoipId, ) -> CallAnswerEventContent
Convenience method to create a VoIP version 0 CallAnswerEventContent with all the required
fields.
Sourcepub fn version_1(
answer: SessionDescription,
call_id: OwnedVoipId,
party_id: OwnedVoipId,
) -> CallAnswerEventContent
pub fn version_1( answer: SessionDescription, call_id: OwnedVoipId, party_id: OwnedVoipId, ) -> CallAnswerEventContent
Convenience method to create a VoIP version 1 CallAnswerEventContent with all the required
fields.